export type BaseSearch = {
  pageNo?: number
  pageSize?: number
  [propName: string]: string | number
}
export type LoginDto = {
  username: string
  password: string
}

export type RegisterData = {
  phoneNumber: string
  username: string
  password: string
  busLicense: string
  name?: string
  regCode: string
  legalMan?: string
  address?: string
  captcha: string
  isRead: boolean
  isUnlock: boolean
  companyName?: string
}

export type LoginData = {
  account: string
  password?: string
  captcha?: string
  isUnlock?: boolean
}

export type LoginRespData = {
  address: string
  companyName: string
  legalMan: string
  regCode: string
  url: string
}

export type CaptchaData = {
  account: string
  type: 's_register' | 's_login' | 's_forgot_password'
}

export type CheckCaptchaData = CaptchaData & {
  captcha: string
}

export type ForgetPwdData = {
  account: string
  captcha: string
  newPassword: string
  confirmPassword: string
  token: string
}

export type UserInfo = {
  address: string
  busLicense: string
  cemail: string
  cmobile: string
  cname: string
  cposition: string
  ctelephone: string
  fundDate: string
  id: string
  legalMan: string
  legalTel: string
  name: string
  phoneNumber: string
}
export type LoginInfoRespData = {
  token: string
  userInfo: UserInfo
  userStatus: string
}

// ============ 商品 ===============

// billNo	编码		false	 string
// brandLogo	品牌logo		false	 string
// brandName	品牌名称		false	 string
// brandState	品牌状态 0未启用 1启用		false	 string
// brandStory	品牌故事		false	 string
// brandTag	品牌标签 多个用逗号拼接		false	 string
// brandType	品牌分类		false	 string
// checkState	品牌状态 0待审核 1通过 2拒绝		false	 string
// createBy	创建人		false	 string
// createTime	创建时间		false	 string(date-time)
// createType	品牌状态 1供应商 2运营后台		false	 string
// customCount	关联产品数		false
// integer(int32)
// establishedDate	成立时间		false	 string(date-time)
// headeImage	品牌页头图		false	 string
// id	id		false	 string
// onOrOffTime	上架时间		false	 string(date-time)
// otherImage	其他图片/视频		false	 string
// productionPlaceCode	产地code		false	 string
// productionPlaceName	产地名称		false	 string
// registrationCode	注册地code		false	 string
// reject	拒绝理由		false	 string
// supplierAffiliationId	所属供应商id		false	 string
// supplierAffiliationName	所属供应商名称		false	 string
// thumbnail	品牌页缩略图		false	 string
// trademarkCertificate	商标证书		false	 string
// updateBy	更新人		false	 string
// updateTime	更新时间		false	 string(date-time)
export type BrandItem = Partial<{
  id?: string | number
  brandName: string
  brandStory: string
  brandState: string
  brandTag: string | [] | [string]
  brandTypeArr: []
  brandType_dictText: string
  brandType: string | [] | [string]
  checkState: string
  createType: string
  establishedDate: string
  headeImage: string
  thumbnail: string
  trademarkCertificate: string
  reject?: string
  supplierAffiliationId?: string
  supplierAffiliationName?: string
  affiliationBrandName?: string
  merchandiseEnglishName?: string
  productionPlaceCode?: string
  productionPlaceName?: string
  registrationCode?: string
  onOrOffTime?: string
  otherImage?: string
  otherVideo?: string
  updateBy?: string
  updateTime?: string
  createTime?: string
  createBy?: string
  brandLogo?: string
  brandStoryUrl?: string
  trademarkCertificateUrl?: string
  otherImageUrl?: string
  checkStateName?: string
  createTypeName?: string
  checkState_dictText?: string
}>
// ============ 商品 ===============
export type ProductSearchParams = {
  [key: string]: any
  merchandiseEnglishName: string
}

// createBy	创建人	string
// createTime	创建时间	string
// id	id	string
// maximum	最大数量	integer
// merchandiseId	产品id	string
// minimum	最小数量	integer
// price	单价	number
// updateBy	更新人	string
// updateTime	更新时间	string
export type QuoteItem = Partial<{
  createBy: string
  createTime: string
  id: string
  maximum: number | string
  merchandiseId: string
  minimum: number | string
  price: number | string
  updateBy: string
  updateTime: string
}>

// affiliationBrandCode	所属品牌Code	string
// affiliationBrandName	所属品牌名称	string
// billNo	编码	string
// cartonQuantity	装箱数	integer(int32)
// category	分类	string
// categoryText	产品分类	string
// checkState	审核状态字典	string
// color	颜色	string
// createBy	创建人	string
// createTime	创建时间	string(date-time)
// createType	创建渠道	string
// firstCategory	一级产品分类	string
// height	高	number
// id	id	string
// length	长	number
// lwhUnit	长宽高单位字典code	string
// masterImage	商品主图	string
// merchandiseChinaName	商品中文名称 暂时用不上 忽略	string
// merchandiseDescribe	商品描述	string
// merchandiseEnglishName	商品英文名称	string
// merchandiseType	商品分类字典code 暂时用不上	string
// minMaxPrice	价格区间	string
// moq	MOQ	string
// onOrOffTime	上架时间	string(date-time)
// otherImage	其他图片/视频	string
// otherVideo	其他视频	string
// productCode	产品code	string
// productName	产品名称	string
// quotes	supplier_merchandise_quote	array	supplier_merchandise_quote对象
// registrationCode	产地字典code	string
// reject	拒绝理由	string
// secondCategory	二级产品分类	string
// state	商品上下架状态字典	string
// supplierCode	供应商code	string
// supplierName	供应商name	string
// suttle	净重	string
// suttleUnit	净重单位字典code	string
// tag	标签 多个用逗号拼接	string
// texture	材质	string
// thirdCategory	三级产品分类	string
// twoTitle	副标题	string
// unit	计量单位字典code	string
// updateBy	更新人	string
// updateTime	更新时间	string(date-time)
// volume	体积	number
// volumeUnit	体积字典code	string
// width	宽	number
export type ProductItem = {
  id?: string
  affiliationBrandCode?: string
  affiliationBrandName?: string
  categoryTemporaryArr?: any
  billNo?: string
  cartonQuantity?: number | string
  category?: string
  categoryText?: string
  checkState?: string
  sellPrice?: string
  color?: string
  createBy?: string
  createTime?: string
  createType?: string
  firstCategory?: string
  height?: number | string
  width?: number | string
  length?: number | string
  lwhUnit?: string
  masterImage?: string
  merchandiseChinaName?: string
  merchandiseDescribe?: string
  merchandiseEnglishName?: string
  merchandiseType?: string
  minMaxPrice?: string
  moq?: number | string
  onOrOffTime?: string
  otherImage?: string
  otherVideo?: string
  productCode?: string
  productName?: string
  quotes: Array<QuoteItem>
  registrationCode?: string
  reject?: string
  secondCategory?: string
  state?: string
  supplierCode?: string
  supplierName?: string
  suttle?: string
  suttleUnit?: string
  tag?: string
  texture?: string
  thirdCategory?: string
  twoTitle?: string
  unit?: string
  updateBy?: string
  updateTime?: string
  volume?: number | string
  volumeUnit?: string
  checkState_dictText?: string
}
// 订单
export type OrderItem = {
  id: ''
  createTime: string
}
